# Tests

We use `pytest` to run the tests.

>[!NOTE]
> `pytest` is installed along other dev dependencies

## `tests/end2end`

These tests test the public api like the CLI.
To run them make sure to create venv in each project in `fixtures` and download its dependencies as defined in `requirements.txt`.
